ngff_zarr.from_ngff_zarr - ngff-zarr
Description: Module Contents: Functions:,, from_ngff_zarr, Read an OME-Zarr NGFF Multiscales data structure from a Zarr store.,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.from_ngff_zarr`

## Module Contents

### Functions

`from_ngff_zarr` | Read an OME-Zarr NGFF Multiscales data structure from a Zarr store.

### API

ngff_zarr.from_ngff_zarr.from_ngff_zarr(store: Union[collections.abc.MutableMapping, str, pathlib.Path, zarr.storage.BaseStore]) → ngff_zarr.to_multiscales.Multiscales

  Read an OME-Zarr NGFF Multiscales data structure from a Zarr store.

  store : MutableMapping, str or Path, zarr.storage.BaseStore Store or path to directory in file system.

  ## Returns

  multiscales: multiscale ngff image with dask-chunked arrays for data